@@ -5,8 +5,8 @@ function()
         sprintf("%s%s", toupper(substring(s, 1L, 1L)), substring(s, 2L))
 
     kinds <- lapply(mget(objects(Weka_interfaces), Weka_interfaces),
-                    "[[", "kind")
-    o <- split(names(kinds), sapply(kinds, "[", 1L))
+                    `[[`, "kind")
+    o <- split(names(kinds), sapply(kinds, `[`, 1L))
     names(o) <-
         capitalize(sprintf("%ss",
                            sub(".*_([^_]+)_interface", "\\1", names(o))))
